# sherlock


[![](https://zenodo.org/badge/42115533.svg)](https://zenodo.org/badge/latestdoi/42115533) 


<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/qub-sherlock)](https://pypi.org/project/qub-sherlock/)  
[![](https://img.shields.io/pypi/v/qub-sherlock)](https://pypi.org/project/qub-sherlock/)  
[![](https://img.shields.io/github/license/thespacedoctor/sherlock)](https://github.com/thespacedoctor/sherlock)  
[![](https://img.shields.io/pypi/dm/qub-sherlock)](https://pypi.org/project/qub-sherlock/)  

<!-- STATUS BADGES -->  

[![](http://157.245.42.153:8080/buildStatus/icon?job=sherlock%2Fmaster&subject=build%20master)](http://157.245.42.153:8080/blue/organizations/jenkins/sherlock/activity?branch=master)  
[![](http://157.245.42.153:8080/buildStatus/icon?job=sherlock%2Fdevelop&subject=build%20dev)](http://157.245.42.153:8080/blue/organizations/jenkins/sherlock/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/sherlock@master/coverage.svg)](https://raw.githack.com/thespacedoctor/sherlock/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/qub-sherlock/badge/?version=master)](https://qub-sherlock.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/thespacedoctor/sherlock/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/sherlock/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*mine a library of historical and on-going astronomical survey data in an attempt to identify the sources of transient/variable events, and predict their classifications based on crossmatched data*.

Documentation for sherlock is hosted by [Read the Docs](https://qub-sherlock.readthedocs.io/en/master/) (
[development version](https://qub-sherlock.readthedocs.io/en/develop/) and [master version](https://qub-sherlock.readthedocs.io/en/master/)). The code lives on [github](https://github.com/thespacedoctor/sherlock). Please report any issues you find [here](https://github.com/thespacedoctor/sherlock/issues).

## Features

* 



## How to cite sherlock

If you use `sherlock` in your work, please cite using the following BibTeX entry: 

```bibtex
@software{Young_sherlock,
    author = {Young, David R.},
    doi = {10.5281/zenodo.8038058},
    license = {GPL-3.0-only},
    title = {{sherlock}},
    url = {https://github.com/thespacedoctor/sherlock}
}
```
 
